// dowset.cpp: implementation of the dowset class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "dowset.h"
#include "CSetup.h"
#include "dow95.h"

void printUsage(void);
int isHelpString(char* thisStr);
int isDebugString(char* thisStr);
int isUninstallString(char* thisStr);

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

dowset::dowset()
{

}

dowset::~dowset()
{

}


//////////////////////////////////////////////////////////////////////////////////
//  main -- processes command line arguments and calls the necessary methods.	//
//		arguments -- i/u:  i to install drivers, u to uninstall					//
//					 16/32:  for NT users only, 16 for 16 bit, 32 for 32 bit	//
//		returns -- an integer 0-14 representing the possible outcomes.          //
//////////////////////////////////////////////////////////////////////////////////
int main(int argc, char *argv[])
{
	int i = 0;
	CSetup cSetObj;
	OSVERSIONINFO osvi;
	memset(&osvi, 0, sizeof(OSVERSIONINFO));
	osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
	GetVersionEx(&osvi);

    if ((argc == 2) && (isHelpString(argv[1])))
    {
        printUsage();
        exit (0);
    }

    if ((argc == 3) && (isDebugString(argv[1]) || isDebugString(argv[2]))) 
    { /* debug mode */

        cSetObj.debugMode = 1;
        printf("Debug mode ON\n");

    } /* debug mode */
    else
    { 
        cSetObj.debugMode = 0;
    }

    if ((argc == 3) && (isUninstallString(argv[1]) || isUninstallString(argv[2]))) 
    { /* install mode */

        cSetObj.unInstallMode = 1;
        if (cSetObj.debugMode)
        {
            printf("Uninstall mode selected.\n");
        }

    } /* install mode */
    else
    {
        cSetObj.unInstallMode = 0;
        if (cSetObj.debugMode)
        {
            printf("Regular Install mode selected.\n");
        }
    }

    // Assume both 16-bit and 32-bit drivers required.
    cSetObj.ThirtyTwoBit = true;
    cSetObj.SixteenBit = true;
	
	if(! cSetObj.unInstallMode)
	{
        if (cSetObj.debugMode)
        {
            printf("Calling Install.\n");
        }
		return cSetObj.Install(); // User wants to install drivers.
	}
	else
	{
        if (cSetObj.debugMode)
        {
            printf("Calling Remove.\n");
        }
		return cSetObj.Remove();  // User wants to remove the drivers.
	}

  } /* main */

int isDebugString(char* thisStr)
{ /* isDebugString */
                     
   char tempStr[20];
   tempStr[0] = '\0';
   
   strcpy(tempStr, thisStr);
   if (strcmp(tempStr, "/debug") == 0)
        return (1);
   else
        return (0);

} /* isDebugString */

int isHelpString(char* thisStr)
{ /* isHelpString */
                     
   char tempStr[20];
   tempStr[0] = '\0';
   
   strcpy(tempStr, thisStr);
   if (strcmp(tempStr, "/?") == 0)
        return (1);
   else
        return (0);


} /* isHelpString */

void printUsage(void)
{ /* isHelpString */

    printf("\nUsage:\n\tdowset [/u | /uninstall] [/debug]\n\n");                     

    printf("NOTE:\n\n");
    printf("\t*case sensitive\n");
    printf("\t*installation implied unless /u param specified\n");
    printf("\t*debug mode sends text output to console\n");

} /* isHelpString */

int isUninstallString(char* thisStr)
{ /* isUninstallString */
                     
   char tempStr[20];
   tempStr[0] = '\0';
   
   strcpy(tempStr, thisStr);
   if (strcmp(tempStr, "/u") == 0)
        return (1);
   else if (strcmp(tempStr, "/uninstall") == 0)
        return (1);
   else
        return (0);


} /* isUninstallString */
